@@ -155,13 +155,11 @@ class Client:
             Returns:
                 The row of the Patient, if they are not in the table None is returned
         '''
-        print('Querying patient ' + patient_id + " " + patient_mrn)
         query       = 'SELECT * \
                     FROM `'+self.patient_table_name+'`\
                     WHERE MRN =\'' + patient_mrn +'\'\
                     AND PATIENT_ID =\'' +patient_id + '\''
         rows        = self.__big_query_wrapper.perform_query(query)
-        print('Queried patient ' + patient_id + " " + patient_mrn)
         if rows is None:
             return None
 
@@ -190,12 +188,10 @@ class Client:
         '''
         if patient_row is not None:
             # patient exists, updated patient in table
-            print('Patient exists updating record if necessary')
             return self.__patient_table_update_client.update_patient_in_patient_table(
                 patient_data, patient_row, overwrite=overwrite)
         elif overwrite == False:               
             # if not append to PATIENTS table
-            print('Adding Patient to PATIENTS table')
             return self.__add_data_to_patient_table(patient_data)
         else:
             Helpers.print_error("patient does not exist cannot update")
