@@ -72,13 +72,11 @@ class Client:
             # The Patient Data is updatable so update
             time_now = datetime.datetime.now()
             patient_update_time = datetime.datetime.fromisoformat(patient_row.get("UPDATED_AT"))
-            print('Updating Patient')
             if time_now < patient_update_time + datetime.timedelta(minutes=90):
                 
                 patient_data['UPDATED_AT'] = None
                 patient_data = Helpers.convert_keys_in_dictionary(patient_data)
                 patient_data['action'] = "UPDATED"
-                print('Inserting patient data to holding table')
                 return self.__holding_table_api.insert_data_to_holding_table(patient_data)
 
             return self.__update_patients_table_row_with_dml(patient_data, 
@@ -104,10 +102,8 @@ class Client:
                 Boolean: True if the operation was succesfull, false if otherwise
         '''
         dml_query = self.__create_dml_update_query(patient_data, patient_row)
-        print('performing update query on PATIENTS table')
         if self.__big_query_wrapper.perform_query(dml_query) is None:
             return False
-        print('query performed')
         return True
         
 
